Hex values for five default ggplot colors, with corresponding approximations for three kinds of color blindness. Produced by the `dichromat` package.
Hex values for five default ggplot colors, with corresponding approximations for three kinds of color blindness. Produced by the `dichromat` package.