Learn R Programming

socviz (version 2.0.0)

color_comp: Plot a table of color hex values as a table of colors

Description

Plot a table of color hex values as a table of colors

Usage

color_comp(df)

Value

Plot of table of colors

Arguments

df

data frame of color hex values

Author

Kieran Healy

Details

Given a data frame of color values, plot them as swatches

Examples

Run this code
color_table
color_comp(color_table)

Run the code above in your browser using DataLab