powered by
Plot a table of color hex values as a table of colors
color_comp(df)
Plot of table of colors
data frame of color hex values
Kieran Healy
Given a data frame of color values, plot them as swatches
color_table color_comp(color_table)
Run the code above in your browser using DataLab