Round numeric columns of a data frame or tibble
Details
Takes a data frame or tibble as input, rounds the numeric columns to the specified number of digits.
Examples
head(round_df(iris, 0))
#> Sepal.Length Sepal.Width Petal.Length Petal.Width Species
#> 1 5 4 1 0 setosa
#> 2 5 3 1 0 setosa
#> 3 5 3 1 0 setosa
#> 4 5 3 2 0 setosa
#> 5 5 4 1 0 setosa
#> 6 5 4 2 0 setosa