powered by
Round numeric columns of a data frame or tibble
round_df(data, dig = 2)
An object of the same class as `data`, with the numeric columns rounded off to `dig`
A data frame or tibble
The number of digits to round to
Kieran Healy
Takes a data frame or tibble as input, rounds the numeric columns to the specified number of digits.
head(round_df(iris, 0))
Run the code above in your browser using DataLab